# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from slack_beta_ti.models.api_method_users_get_presence import APIMethodUsersGetPresence
from slack_beta_ti.models.users_conversations_success_schema import UsersConversationsSuccessSchema
from slack_beta_ti.models.users_delete_photo_schema import UsersDeletePhotoSchema
from slack_beta_ti.models.users_info_success_schema import UsersInfoSuccessSchema
from slack_beta_ti.models.users_list_schema import UsersListSchema
from slack_beta_ti.models.users_lookup_by_email_success_schema import UsersLookupByEmailSuccessSchema
from slack_beta_ti.models.users_profile_get_schema import UsersProfileGetSchema
from slack_beta_ti.models.users_profile_set_schema import UsersProfileSetSchema
from slack_beta_ti.models.users_set_active_schema import UsersSetActiveSchema
from slack_beta_ti.models.users_set_photo_schema import UsersSetPhotoSchema
from slack_beta_ti.models.users_set_presence_schema import UsersSetPresenceSchema

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class UsersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def users_conversations(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `conversations:read`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.")] = None,
        types: Annotated[Optional[StrictStr], Field(description="Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`")] = None,
        exclude_archived: Annotated[Optional[StrictBool], Field(description="Set to `true` to exclude archived channels from the list")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersConversationsSuccessSchema:
        """users_conversations

        List conversations the calling user may access.

        :param token: Authentication token. Requires scope: `conversations:read`
        :type token: str
        :param user: Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.
        :type user: str
        :param types: Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
        :type types: str
        :param exclude_archived: Set to `true` to exclude archived channels from the list
        :type exclude_archived: bool
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_conversations_serialize(
            token=token,
            user=user,
            types=types,
            exclude_archived=exclude_archived,
            limit=limit,
            cursor=cursor,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersConversationsSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_conversations_with_http_info(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `conversations:read`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.")] = None,
        types: Annotated[Optional[StrictStr], Field(description="Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`")] = None,
        exclude_archived: Annotated[Optional[StrictBool], Field(description="Set to `true` to exclude archived channels from the list")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersConversationsSuccessSchema]:
        """users_conversations

        List conversations the calling user may access.

        :param token: Authentication token. Requires scope: `conversations:read`
        :type token: str
        :param user: Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.
        :type user: str
        :param types: Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
        :type types: str
        :param exclude_archived: Set to `true` to exclude archived channels from the list
        :type exclude_archived: bool
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_conversations_serialize(
            token=token,
            user=user,
            types=types,
            exclude_archived=exclude_archived,
            limit=limit,
            cursor=cursor,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersConversationsSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_conversations_without_preload_content(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `conversations:read`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.")] = None,
        types: Annotated[Optional[StrictStr], Field(description="Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`")] = None,
        exclude_archived: Annotated[Optional[StrictBool], Field(description="Set to `true` to exclude archived channels from the list")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_conversations

        List conversations the calling user may access.

        :param token: Authentication token. Requires scope: `conversations:read`
        :type token: str
        :param user: Browse conversations by a specific user ID's membership. Non-public channels are restricted to those where the calling user shares membership.
        :type user: str
        :param types: Mix and match channel types by providing a comma-separated list of any combination of `public_channel`, `private_channel`, `mpim`, `im`
        :type types: str
        :param exclude_archived: Set to `true` to exclude archived channels from the list
        :type exclude_archived: bool
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn't been reached. Must be an integer no larger than 1000.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_conversations_serialize(
            token=token,
            user=user,
            types=types,
            exclude_archived=exclude_archived,
            limit=limit,
            cursor=cursor,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersConversationsSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_conversations_serialize(
        self,
        token,
        user,
        types,
        exclude_archived,
        limit,
        cursor,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if user is not None:
            
            _query_params.append(('user', user))
            
        if types is not None:
            
            _query_params.append(('types', types))
            
        if exclude_archived is not None:
            
            _query_params.append(('exclude_archived', exclude_archived))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.conversations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_delete_photo(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersDeletePhotoSchema:
        """users_delete_photo

        Delete the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_delete_photo_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersDeletePhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_delete_photo_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersDeletePhotoSchema]:
        """users_delete_photo

        Delete the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_delete_photo_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersDeletePhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_delete_photo_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_delete_photo

        Delete the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_delete_photo_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersDeletePhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_delete_photo_serialize(
        self,
        token,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if token is not None:
            _form_params.append(('token', token))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/users.deletePhoto',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_get_presence(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        user: Annotated[Optional[StrictStr], Field(description="User to get presence info on. Defaults to the authed user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> APIMethodUsersGetPresence:
        """users_get_presence

        Gets user presence information.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param user: User to get presence info on. Defaults to the authed user.
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_get_presence_serialize(
            token=token,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "APIMethodUsersGetPresence",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_get_presence_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        user: Annotated[Optional[StrictStr], Field(description="User to get presence info on. Defaults to the authed user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[APIMethodUsersGetPresence]:
        """users_get_presence

        Gets user presence information.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param user: User to get presence info on. Defaults to the authed user.
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_get_presence_serialize(
            token=token,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "APIMethodUsersGetPresence",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_get_presence_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        user: Annotated[Optional[StrictStr], Field(description="User to get presence info on. Defaults to the authed user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_get_presence

        Gets user presence information.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param user: User to get presence info on. Defaults to the authed user.
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_get_presence_serialize(
            token=token,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "APIMethodUsersGetPresence",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_get_presence_serialize(
        self,
        token,
        user,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if user is not None:
            
            _query_params.append(('user', user))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.getPresence',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_identity(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `identity.basic`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> List[str]:
        """users_identity

        Get a user's identity.

        :param token: Authentication token. Requires scope: `identity.basic`
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_identity_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_identity_with_http_info(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `identity.basic`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[List[str]]:
        """users_identity

        Get a user's identity.

        :param token: Authentication token. Requires scope: `identity.basic`
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_identity_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_identity_without_preload_content(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `identity.basic`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_identity

        Get a user's identity.

        :param token: Authentication token. Requires scope: `identity.basic`
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_identity_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[str]",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_identity_serialize(
        self,
        token,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.identity',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for this user. Defaults to `false`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to get info on")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersInfoSuccessSchema:
        """users_info

        Gets information about a user.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param include_locale: Set this to `true` to receive the locale for this user. Defaults to `false`
        :type include_locale: bool
        :param user: User to get info on
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_info_serialize(
            token=token,
            include_locale=include_locale,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersInfoSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_info_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for this user. Defaults to `false`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to get info on")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersInfoSuccessSchema]:
        """users_info

        Gets information about a user.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param include_locale: Set this to `true` to receive the locale for this user. Defaults to `false`
        :type include_locale: bool
        :param user: User to get info on
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_info_serialize(
            token=token,
            include_locale=include_locale,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersInfoSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_info_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read`")],
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for this user. Defaults to `false`")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to get info on")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_info

        Gets information about a user.

        :param token: Authentication token. Requires scope: `users:read` (required)
        :type token: str
        :param include_locale: Set this to `true` to receive the locale for this user. Defaults to `false`
        :type include_locale: bool
        :param user: User to get info on
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_info_serialize(
            token=token,
            include_locale=include_locale,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersInfoSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_info_serialize(
        self,
        token,
        include_locale,
        user,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if include_locale is not None:
            
            _query_params.append(('include_locale', include_locale))
            
        if user is not None:
            
            _query_params.append(('user', user))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.info',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_list(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `users:read`")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for users. Defaults to `false`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersListSchema:
        """users_list

        Lists all users in a Slack team.

        :param token: Authentication token. Requires scope: `users:read`
        :type token: str
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :param include_locale: Set this to `true` to receive the locale for users. Defaults to `false`
        :type include_locale: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_list_serialize(
            token=token,
            limit=limit,
            cursor=cursor,
            include_locale=include_locale,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_list_with_http_info(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `users:read`")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for users. Defaults to `false`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersListSchema]:
        """users_list

        Lists all users in a Slack team.

        :param token: Authentication token. Requires scope: `users:read`
        :type token: str
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :param include_locale: Set this to `true` to receive the locale for users. Defaults to `false`
        :type include_locale: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_list_serialize(
            token=token,
            limit=limit,
            cursor=cursor,
            include_locale=include_locale,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_list_without_preload_content(
        self,
        token: Annotated[Optional[StrictStr], Field(description="Authentication token. Requires scope: `users:read`")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.")] = None,
        include_locale: Annotated[Optional[StrictBool], Field(description="Set this to `true` to receive the locale for users. Defaults to `false`")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_list

        Lists all users in a Slack team.

        :param token: Authentication token. Requires scope: `users:read`
        :type token: str
        :param limit: The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn't been reached. Providing no `limit` value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience `limit_required` or HTTP 500 errors.
        :type limit: int
        :param cursor: Paginate through collections of data by setting the `cursor` parameter to a `next_cursor` attribute returned by a previous request's `response_metadata`. Default value fetches the first \"page\" of the collection. See [pagination](/docs/pagination) for more detail.
        :type cursor: str
        :param include_locale: Set this to `true` to receive the locale for users. Defaults to `false`
        :type include_locale: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_list_serialize(
            token=token,
            limit=limit,
            cursor=cursor,
            include_locale=include_locale,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersListSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_list_serialize(
        self,
        token,
        limit,
        cursor,
        include_locale,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if include_locale is not None:
            
            _query_params.append(('include_locale', include_locale))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_lookup_by_email(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read.email`")],
        email: Annotated[StrictStr, Field(description="An email address belonging to a user in the workspace")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersLookupByEmailSuccessSchema:
        """users_lookup_by_email

        Find a user with an email address.

        :param token: Authentication token. Requires scope: `users:read.email` (required)
        :type token: str
        :param email: An email address belonging to a user in the workspace (required)
        :type email: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_lookup_by_email_serialize(
            token=token,
            email=email,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersLookupByEmailSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_lookup_by_email_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read.email`")],
        email: Annotated[StrictStr, Field(description="An email address belonging to a user in the workspace")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersLookupByEmailSuccessSchema]:
        """users_lookup_by_email

        Find a user with an email address.

        :param token: Authentication token. Requires scope: `users:read.email` (required)
        :type token: str
        :param email: An email address belonging to a user in the workspace (required)
        :type email: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_lookup_by_email_serialize(
            token=token,
            email=email,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersLookupByEmailSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_lookup_by_email_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:read.email`")],
        email: Annotated[StrictStr, Field(description="An email address belonging to a user in the workspace")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_lookup_by_email

        Find a user with an email address.

        :param token: Authentication token. Requires scope: `users:read.email` (required)
        :type token: str
        :param email: An email address belonging to a user in the workspace (required)
        :type email: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_lookup_by_email_serialize(
            token=token,
            email=email,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersLookupByEmailSuccessSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_lookup_by_email_serialize(
        self,
        token,
        email,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if email is not None:
            
            _query_params.append(('email', email))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.lookupByEmail',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_profile_get(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:read`")],
        include_labels: Annotated[Optional[StrictBool], Field(description="Include labels for each ID in custom profile fields")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to retrieve profile info for")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersProfileGetSchema:
        """users_profile_get

        Retrieves a user's profile information.

        :param token: Authentication token. Requires scope: `users.profile:read` (required)
        :type token: str
        :param include_labels: Include labels for each ID in custom profile fields
        :type include_labels: bool
        :param user: User to retrieve profile info for
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_get_serialize(
            token=token,
            include_labels=include_labels,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileGetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_profile_get_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:read`")],
        include_labels: Annotated[Optional[StrictBool], Field(description="Include labels for each ID in custom profile fields")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to retrieve profile info for")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersProfileGetSchema]:
        """users_profile_get

        Retrieves a user's profile information.

        :param token: Authentication token. Requires scope: `users.profile:read` (required)
        :type token: str
        :param include_labels: Include labels for each ID in custom profile fields
        :type include_labels: bool
        :param user: User to retrieve profile info for
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_get_serialize(
            token=token,
            include_labels=include_labels,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileGetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_profile_get_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:read`")],
        include_labels: Annotated[Optional[StrictBool], Field(description="Include labels for each ID in custom profile fields")] = None,
        user: Annotated[Optional[StrictStr], Field(description="User to retrieve profile info for")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_profile_get

        Retrieves a user's profile information.

        :param token: Authentication token. Requires scope: `users.profile:read` (required)
        :type token: str
        :param include_labels: Include labels for each ID in custom profile fields
        :type include_labels: bool
        :param user: User to retrieve profile info for
        :type user: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_get_serialize(
            token=token,
            include_labels=include_labels,
            user=user,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileGetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_profile_get_serialize(
        self,
        token,
        include_labels,
        user,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        if include_labels is not None:
            
            _query_params.append(('include_labels', include_labels))
            
        if user is not None:
            
            _query_params.append(('user', user))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/users.profile.get',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_profile_set(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        name: Annotated[Optional[StrictStr], Field(description="Name of a single key to set. Usable only if `profile` is not passed.")] = None,
        profile: Annotated[Optional[StrictStr], Field(description="Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.")] = None,
        user: Annotated[Optional[StrictStr], Field(description="ID of user to change. This argument may only be specified by team admins on paid teams.")] = None,
        value: Annotated[Optional[StrictStr], Field(description="Value to set a single key to. Usable only if `profile` is not passed.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersProfileSetSchema:
        """users_profile_set

        Set the profile information for a user.

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param name: Name of a single key to set. Usable only if `profile` is not passed.
        :type name: str
        :param profile: Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.
        :type profile: str
        :param user: ID of user to change. This argument may only be specified by team admins on paid teams.
        :type user: str
        :param value: Value to set a single key to. Usable only if `profile` is not passed.
        :type value: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_set_serialize(
            token=token,
            name=name,
            profile=profile,
            user=user,
            value=value,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileSetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_profile_set_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        name: Annotated[Optional[StrictStr], Field(description="Name of a single key to set. Usable only if `profile` is not passed.")] = None,
        profile: Annotated[Optional[StrictStr], Field(description="Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.")] = None,
        user: Annotated[Optional[StrictStr], Field(description="ID of user to change. This argument may only be specified by team admins on paid teams.")] = None,
        value: Annotated[Optional[StrictStr], Field(description="Value to set a single key to. Usable only if `profile` is not passed.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersProfileSetSchema]:
        """users_profile_set

        Set the profile information for a user.

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param name: Name of a single key to set. Usable only if `profile` is not passed.
        :type name: str
        :param profile: Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.
        :type profile: str
        :param user: ID of user to change. This argument may only be specified by team admins on paid teams.
        :type user: str
        :param value: Value to set a single key to. Usable only if `profile` is not passed.
        :type value: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_set_serialize(
            token=token,
            name=name,
            profile=profile,
            user=user,
            value=value,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileSetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_profile_set_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        name: Annotated[Optional[StrictStr], Field(description="Name of a single key to set. Usable only if `profile` is not passed.")] = None,
        profile: Annotated[Optional[StrictStr], Field(description="Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.")] = None,
        user: Annotated[Optional[StrictStr], Field(description="ID of user to change. This argument may only be specified by team admins on paid teams.")] = None,
        value: Annotated[Optional[StrictStr], Field(description="Value to set a single key to. Usable only if `profile` is not passed.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_profile_set

        Set the profile information for a user.

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param name: Name of a single key to set. Usable only if `profile` is not passed.
        :type name: str
        :param profile: Collection of key:value pairs presented as a URL-encoded JSON hash. At most 50 fields may be set. Each field name is limited to 255 characters.
        :type profile: str
        :param user: ID of user to change. This argument may only be specified by team admins on paid teams.
        :type user: str
        :param value: Value to set a single key to. Usable only if `profile` is not passed.
        :type value: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_profile_set_serialize(
            token=token,
            name=name,
            profile=profile,
            user=user,
            value=value,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersProfileSetSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_profile_set_serialize(
        self,
        token,
        name,
        profile,
        user,
        value,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if name is not None:
            _form_params.append(('name', name))
        if profile is not None:
            _form_params.append(('profile', profile))
        if user is not None:
            _form_params.append(('user', user))
        if value is not None:
            _form_params.append(('value', value))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/users.profile.set',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_set_active(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersSetActiveSchema:
        """users_set_active

        Marked a user as active. Deprecated and non-functional.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_active_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetActiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_set_active_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersSetActiveSchema]:
        """users_set_active

        Marked a user as active. Deprecated and non-functional.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_active_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetActiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_set_active_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_set_active

        Marked a user as active. Deprecated and non-functional.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_active_serialize(
            token=token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetActiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_set_active_serialize(
        self,
        token,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/users.setActive',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_set_photo(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        crop_w: Annotated[Optional[StrictStr], Field(description="Width/height of crop box (always square)")] = None,
        crop_x: Annotated[Optional[StrictStr], Field(description="X coordinate of top-left corner of crop box")] = None,
        crop_y: Annotated[Optional[StrictStr], Field(description="Y coordinate of top-left corner of crop box")] = None,
        image: Annotated[Optional[StrictStr], Field(description="File contents via `multipart/form-data`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersSetPhotoSchema:
        """users_set_photo

        Set the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param crop_w: Width/height of crop box (always square)
        :type crop_w: str
        :param crop_x: X coordinate of top-left corner of crop box
        :type crop_x: str
        :param crop_y: Y coordinate of top-left corner of crop box
        :type crop_y: str
        :param image: File contents via `multipart/form-data`.
        :type image: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_photo_serialize(
            token=token,
            crop_w=crop_w,
            crop_x=crop_x,
            crop_y=crop_y,
            image=image,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_set_photo_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        crop_w: Annotated[Optional[StrictStr], Field(description="Width/height of crop box (always square)")] = None,
        crop_x: Annotated[Optional[StrictStr], Field(description="X coordinate of top-left corner of crop box")] = None,
        crop_y: Annotated[Optional[StrictStr], Field(description="Y coordinate of top-left corner of crop box")] = None,
        image: Annotated[Optional[StrictStr], Field(description="File contents via `multipart/form-data`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersSetPhotoSchema]:
        """users_set_photo

        Set the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param crop_w: Width/height of crop box (always square)
        :type crop_w: str
        :param crop_x: X coordinate of top-left corner of crop box
        :type crop_x: str
        :param crop_y: Y coordinate of top-left corner of crop box
        :type crop_y: str
        :param image: File contents via `multipart/form-data`.
        :type image: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_photo_serialize(
            token=token,
            crop_w=crop_w,
            crop_x=crop_x,
            crop_y=crop_y,
            image=image,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_set_photo_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users.profile:write`")],
        crop_w: Annotated[Optional[StrictStr], Field(description="Width/height of crop box (always square)")] = None,
        crop_x: Annotated[Optional[StrictStr], Field(description="X coordinate of top-left corner of crop box")] = None,
        crop_y: Annotated[Optional[StrictStr], Field(description="Y coordinate of top-left corner of crop box")] = None,
        image: Annotated[Optional[StrictStr], Field(description="File contents via `multipart/form-data`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_set_photo

        Set the user profile photo

        :param token: Authentication token. Requires scope: `users.profile:write` (required)
        :type token: str
        :param crop_w: Width/height of crop box (always square)
        :type crop_w: str
        :param crop_x: X coordinate of top-left corner of crop box
        :type crop_x: str
        :param crop_y: Y coordinate of top-left corner of crop box
        :type crop_y: str
        :param image: File contents via `multipart/form-data`.
        :type image: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_photo_serialize(
            token=token,
            crop_w=crop_w,
            crop_x=crop_x,
            crop_y=crop_y,
            image=image,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPhotoSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_set_photo_serialize(
        self,
        token,
        crop_w,
        crop_x,
        crop_y,
        image,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if token is not None:
            _form_params.append(('token', token))
        if crop_w is not None:
            _form_params.append(('crop_w', crop_w))
        if crop_x is not None:
            _form_params.append(('crop_x', crop_x))
        if crop_y is not None:
            _form_params.append(('crop_y', crop_y))
        if image is not None:
            _form_params.append(('image', image))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/users.setPhoto',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def users_set_presence(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        presence: Annotated[StrictStr, Field(description="Either `auto` or `away`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> UsersSetPresenceSchema:
        """users_set_presence

        Manually sets user presence.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :param presence: Either `auto` or `away` (required)
        :type presence: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_presence_serialize(
            token=token,
            presence=presence,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPresenceSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def users_set_presence_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        presence: Annotated[StrictStr, Field(description="Either `auto` or `away`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[UsersSetPresenceSchema]:
        """users_set_presence

        Manually sets user presence.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :param presence: Either `auto` or `away` (required)
        :type presence: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_presence_serialize(
            token=token,
            presence=presence,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPresenceSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def users_set_presence_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `users:write`")],
        presence: Annotated[StrictStr, Field(description="Either `auto` or `away`")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """users_set_presence

        Manually sets user presence.

        :param token: Authentication token. Requires scope: `users:write` (required)
        :type token: str
        :param presence: Either `auto` or `away` (required)
        :type presence: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._users_set_presence_serialize(
            token=token,
            presence=presence,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UsersSetPresenceSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _users_set_presence_serialize(
        self,
        token,
        presence,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if presence is not None:
            _form_params.append(('presence', presence))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/users.setPresence',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.chat_schedule_message_success_schema import ChatScheduleMessageSuccessSchema

class TestChatScheduleMessageSuccessSchema(unittest.TestCase):
    """ChatScheduleMessageSuccessSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatScheduleMessageSuccessSchema:
        """Test ChatScheduleMessageSuccessSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatScheduleMessageSuccessSchema`
        """
        model = ChatScheduleMessageSuccessSchema()
        if include_optional:
            return ChatScheduleMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = None,
                ok = True,
                post_at = 56,
                scheduled_message_id = 'QQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
            )
        else:
            return ChatScheduleMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = None,
                ok = True,
                post_at = 56,
                scheduled_message_id = 'QQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
        )
        """

    def testChatScheduleMessageSuccessSchema(self):
        """Test ChatScheduleMessageSuccessSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1"

# import apis into sdk package
from slack_beta_ti.api.admin_api import AdminApi
from slack_beta_ti.api.admin_apps_api import AdminAppsApi
from slack_beta_ti.api.admin_apps_approved_api import AdminAppsApprovedApi
from slack_beta_ti.api.admin_apps_requests_api import AdminAppsRequestsApi
from slack_beta_ti.api.admin_apps_restricted_api import AdminAppsRestrictedApi
from slack_beta_ti.api.admin_conversations_api import AdminConversationsApi
from slack_beta_ti.api.admin_conversations_ekm_api import AdminConversationsEkmApi
from slack_beta_ti.api.admin_conversations_restrict_access_api import AdminConversationsRestrictAccessApi
from slack_beta_ti.api.admin_emoji_api import AdminEmojiApi
from slack_beta_ti.api.admin_invite_requests_api import AdminInviteRequestsApi
from slack_beta_ti.api.admin_invite_requests_approved_api import AdminInviteRequestsApprovedApi
from slack_beta_ti.api.admin_invite_requests_denied_api import AdminInviteRequestsDeniedApi
from slack_beta_ti.api.admin_teams_api import AdminTeamsApi
from slack_beta_ti.api.admin_teams_admins_api import AdminTeamsAdminsApi
from slack_beta_ti.api.admin_teams_owners_api import AdminTeamsOwnersApi
from slack_beta_ti.api.admin_teams_settings_api import AdminTeamsSettingsApi
from slack_beta_ti.api.admin_usergroups_api import AdminUsergroupsApi
from slack_beta_ti.api.admin_users_api import AdminUsersApi
from slack_beta_ti.api.admin_users_session_api import AdminUsersSessionApi
from slack_beta_ti.api.api_api import ApiApi
from slack_beta_ti.api.apps_api import AppsApi
from slack_beta_ti.api.apps_event_authorizations_api import AppsEventAuthorizationsApi
from slack_beta_ti.api.apps_permissions_api import AppsPermissionsApi
from slack_beta_ti.api.apps_permissions_resources_api import AppsPermissionsResourcesApi
from slack_beta_ti.api.apps_permissions_scopes_api import AppsPermissionsScopesApi
from slack_beta_ti.api.apps_permissions_users_api import AppsPermissionsUsersApi
from slack_beta_ti.api.auth_api import AuthApi
from slack_beta_ti.api.bots_api import BotsApi
from slack_beta_ti.api.calls_api import CallsApi
from slack_beta_ti.api.calls_participants_api import CallsParticipantsApi
from slack_beta_ti.api.chat_api import ChatApi
from slack_beta_ti.api.chat_scheduled_messages_api import ChatScheduledMessagesApi
from slack_beta_ti.api.conversations_api import ConversationsApi
from slack_beta_ti.api.dialog_api import DialogApi
from slack_beta_ti.api.dnd_api import DndApi
from slack_beta_ti.api.emoji_api import EmojiApi
from slack_beta_ti.api.files_api import FilesApi
from slack_beta_ti.api.files_comments_api import FilesCommentsApi
from slack_beta_ti.api.files_remote_api import FilesRemoteApi
from slack_beta_ti.api.migration_api import MigrationApi
from slack_beta_ti.api.oauth_api import OauthApi
from slack_beta_ti.api.oauth_v2_api import OauthV2Api
from slack_beta_ti.api.pins_api import PinsApi
from slack_beta_ti.api.reactions_api import ReactionsApi
from slack_beta_ti.api.reminders_api import RemindersApi
from slack_beta_ti.api.rtm_api import RtmApi
from slack_beta_ti.api.search_api import SearchApi
from slack_beta_ti.api.stars_api import StarsApi
from slack_beta_ti.api.team_api import TeamApi
from slack_beta_ti.api.team_profile_api import TeamProfileApi
from slack_beta_ti.api.usergroups_api import UsergroupsApi
from slack_beta_ti.api.usergroups_users_api import UsergroupsUsersApi
from slack_beta_ti.api.users_api import UsersApi
from slack_beta_ti.api.users_profile_api import UsersProfileApi
from slack_beta_ti.api.views_api import ViewsApi
from slack_beta_ti.api.workflows_api import WorkflowsApi

# import ApiClient
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.api_client import ApiClient
from slack_beta_ti.configuration import Configuration
from slack_beta_ti.exceptions import OpenApiException
from slack_beta_ti.exceptions import ApiTypeError
from slack_beta_ti.exceptions import ApiValueError
from slack_beta_ti.exceptions import ApiKeyError
from slack_beta_ti.exceptions import ApiAttributeError
from slack_beta_ti.exceptions import ApiException

# import models into sdk package
from slack_beta_ti.models.api_method_users_get_presence import APIMethodUsersGetPresence
from slack_beta_ti.models.admin_apps_approve_request import AdminAppsApproveRequest
from slack_beta_ti.models.admin_apps_restrict_request import AdminAppsRestrictRequest
from slack_beta_ti.models.admin_conversations_archive_error_schema import AdminConversationsArchiveErrorSchema
from slack_beta_ti.models.admin_conversations_archive_request import AdminConversationsArchiveRequest
from slack_beta_ti.models.admin_conversations_archive_schema import AdminConversationsArchiveSchema
from slack_beta_ti.models.admin_conversations_convert_to_private_error_schema import AdminConversationsConvertToPrivateErrorSchema
from slack_beta_ti.models.admin_conversations_convert_to_private_request import AdminConversationsConvertToPrivateRequest
from slack_beta_ti.models.admin_conversations_convert_to_private_schema import AdminConversationsConvertToPrivateSchema
from slack_beta_ti.models.admin_conversations_create_error_schema import AdminConversationsCreateErrorSchema
from slack_beta_ti.models.admin_conversations_create_request import AdminConversationsCreateRequest
from slack_beta_ti.models.admin_conversations_create_schema import AdminConversationsCreateSchema
from slack_beta_ti.models.admin_conversations_delete_error_schema import AdminConversationsDeleteErrorSchema
from slack_beta_ti.models.admin_conversations_delete_request import AdminConversationsDeleteRequest
from slack_beta_ti.models.admin_conversations_delete_schema import AdminConversationsDeleteSchema
from slack_beta_ti.models.admin_conversations_disconnect_shared_error_schema import AdminConversationsDisconnectSharedErrorSchema
from slack_beta_ti.models.admin_conversations_disconnect_shared_request import AdminConversationsDisconnectSharedRequest
from slack_beta_ti.models.admin_conversations_get_conversation_prefs_schema import AdminConversationsGetConversationPrefsSchema
from slack_beta_ti.models.admin_conversations_get_conversation_prefs_schema_prefs import AdminConversationsGetConversationPrefsSchemaPrefs
from slack_beta_ti.models.admin_conversations_get_conversation_prefs_schema_prefs_can_thread import AdminConversationsGetConversationPrefsSchemaPrefsCanThread
from slack_beta_ti.models.admin_conversations_get_teams_error_schema import AdminConversationsGetTeamsErrorSchema
from slack_beta_ti.models.admin_conversations_get_teams_schema import AdminConversationsGetTeamsSchema
from slack_beta_ti.models.admin_conversations_invite_error_schema import AdminConversationsInviteErrorSchema
from slack_beta_ti.models.admin_conversations_invite_request import AdminConversationsInviteRequest
from slack_beta_ti.models.admin_conversations_invite_schema import AdminConversationsInviteSchema
from slack_beta_ti.models.admin_conversations_rename_request import AdminConversationsRenameRequest
from slack_beta_ti.models.admin_conversations_rename_schema import AdminConversationsRenameSchema
from slack_beta_ti.models.admin_conversations_rename_schema1 import AdminConversationsRenameSchema1
from slack_beta_ti.models.admin_conversations_search_error_schema import AdminConversationsSearchErrorSchema
from slack_beta_ti.models.admin_conversations_search_schema import AdminConversationsSearchSchema
from slack_beta_ti.models.admin_conversations_set_conversation_prefs_error_schema import AdminConversationsSetConversationPrefsErrorSchema
from slack_beta_ti.models.admin_conversations_set_conversation_prefs_request import AdminConversationsSetConversationPrefsRequest
from slack_beta_ti.models.admin_conversations_set_conversation_prefs_schema import AdminConversationsSetConversationPrefsSchema
from slack_beta_ti.models.admin_conversations_set_teams_request import AdminConversationsSetTeamsRequest
from slack_beta_ti.models.admin_conversations_unarchive_error_schema import AdminConversationsUnarchiveErrorSchema
from slack_beta_ti.models.admin_conversations_unarchive_error_schema1 import AdminConversationsUnarchiveErrorSchema1
from slack_beta_ti.models.admin_conversations_unarchive_error_schema2 import AdminConversationsUnarchiveErrorSchema2
from slack_beta_ti.models.admin_conversations_unarchive_request import AdminConversationsUnarchiveRequest
from slack_beta_ti.models.admin_conversations_unarchive_schema import AdminConversationsUnarchiveSchema
from slack_beta_ti.models.admin_invite_requests_approve_request import AdminInviteRequestsApproveRequest
from slack_beta_ti.models.admin_teams_create_request import AdminTeamsCreateRequest
from slack_beta_ti.models.admin_teams_settings_set_description_request import AdminTeamsSettingsSetDescriptionRequest
from slack_beta_ti.models.admin_teams_settings_set_discoverability_request import AdminTeamsSettingsSetDiscoverabilityRequest
from slack_beta_ti.models.admin_teams_settings_set_name_request import AdminTeamsSettingsSetNameRequest
from slack_beta_ti.models.admin_usergroups_add_channels_request import AdminUsergroupsAddChannelsRequest
from slack_beta_ti.models.admin_usergroups_add_teams_request import AdminUsergroupsAddTeamsRequest
from slack_beta_ti.models.admin_usergroups_remove_channels_request import AdminUsergroupsRemoveChannelsRequest
from slack_beta_ti.models.admin_users_assign_request import AdminUsersAssignRequest
from slack_beta_ti.models.admin_users_invite_request import AdminUsersInviteRequest
from slack_beta_ti.models.admin_users_remove_request import AdminUsersRemoveRequest
from slack_beta_ti.models.admin_users_session_invalidate_request import AdminUsersSessionInvalidateRequest
from slack_beta_ti.models.admin_users_session_reset_request import AdminUsersSessionResetRequest
from slack_beta_ti.models.admin_users_set_admin_request import AdminUsersSetAdminRequest
from slack_beta_ti.models.admin_users_set_expiration_request import AdminUsersSetExpirationRequest
from slack_beta_ti.models.admin_users_set_owner_request import AdminUsersSetOwnerRequest
from slack_beta_ti.models.admin_users_set_regular_request import AdminUsersSetRegularRequest
from slack_beta_ti.models.api_permissions_scopes_list_success_schema import ApiPermissionsScopesListSuccessSchema
from slack_beta_ti.models.api_test_error_schema import ApiTestErrorSchema
from slack_beta_ti.models.api_test_success_schema import ApiTestSuccessSchema
from slack_beta_ti.models.apps_permissions_info_error_schema import AppsPermissionsInfoErrorSchema
from slack_beta_ti.models.apps_permissions_info_schema import AppsPermissionsInfoSchema
from slack_beta_ti.models.apps_permissions_info_schema_info import AppsPermissionsInfoSchemaInfo
from slack_beta_ti.models.apps_permissions_info_schema_info_app_home import AppsPermissionsInfoSchemaInfoAppHome
from slack_beta_ti.models.apps_permissions_info_schema_info_team import AppsPermissionsInfoSchemaInfoTeam
from slack_beta_ti.models.apps_permissions_request_error_schema import AppsPermissionsRequestErrorSchema
from slack_beta_ti.models.apps_permissions_request_schema import AppsPermissionsRequestSchema
from slack_beta_ti.models.apps_permissions_resources_list_error_schema import AppsPermissionsResourcesListErrorSchema
from slack_beta_ti.models.apps_permissions_resources_list_success_schema import AppsPermissionsResourcesListSuccessSchema
from slack_beta_ti.models.apps_permissions_resources_list_success_schema_resources_inner import AppsPermissionsResourcesListSuccessSchemaResourcesInner
from slack_beta_ti.models.apps_permissions_scopes_list_error_schema import AppsPermissionsScopesListErrorSchema
from slack_beta_ti.models.apps_uninstall_error_schema import AppsUninstallErrorSchema
from slack_beta_ti.models.apps_uninstall_schema import AppsUninstallSchema
from slack_beta_ti.models.auth_revoke_error_schema import AuthRevokeErrorSchema
from slack_beta_ti.models.auth_revoke_schema import AuthRevokeSchema
from slack_beta_ti.models.auth_test_error_schema import AuthTestErrorSchema
from slack_beta_ti.models.auth_test_success_schema import AuthTestSuccessSchema
from slack_beta_ti.models.bots_info_error_schema import BotsInfoErrorSchema
from slack_beta_ti.models.bots_info_schema import BotsInfoSchema
from slack_beta_ti.models.calls_add_request import CallsAddRequest
from slack_beta_ti.models.calls_end_request import CallsEndRequest
from slack_beta_ti.models.calls_participants_add_request import CallsParticipantsAddRequest
from slack_beta_ti.models.calls_participants_remove_request import CallsParticipantsRemoveRequest
from slack_beta_ti.models.calls_update_request import CallsUpdateRequest
from slack_beta_ti.models.chat_delete_error_schema import ChatDeleteErrorSchema
from slack_beta_ti.models.chat_delete_request import ChatDeleteRequest
from slack_beta_ti.models.chat_delete_scheduled_message_error_schema import ChatDeleteScheduledMessageErrorSchema
from slack_beta_ti.models.chat_delete_scheduled_message_request import ChatDeleteScheduledMessageRequest
from slack_beta_ti.models.chat_delete_scheduled_message_schema import ChatDeleteScheduledMessageSchema
from slack_beta_ti.models.chat_delete_success_schema import ChatDeleteSuccessSchema
from slack_beta_ti.models.chat_get_permalink_error_schema import ChatGetPermalinkErrorSchema
from slack_beta_ti.models.chat_get_permalink_success_schema import ChatGetPermalinkSuccessSchema
from slack_beta_ti.models.chat_me_message_error_schema import ChatMeMessageErrorSchema
from slack_beta_ti.models.chat_me_message_request import ChatMeMessageRequest
from slack_beta_ti.models.chat_me_message_schema import ChatMeMessageSchema
from slack_beta_ti.models.chat_post_ephemeral_error_schema import ChatPostEphemeralErrorSchema
from slack_beta_ti.models.chat_post_ephemeral_request import ChatPostEphemeralRequest
from slack_beta_ti.models.chat_post_ephemeral_success_schema import ChatPostEphemeralSuccessSchema
from slack_beta_ti.models.chat_post_message_error_schema import ChatPostMessageErrorSchema
from slack_beta_ti.models.chat_post_message_request import ChatPostMessageRequest
from slack_beta_ti.models.chat_post_message_success_schema import ChatPostMessageSuccessSchema
from slack_beta_ti.models.chat_schedule_message_error_schema import ChatScheduleMessageErrorSchema
from slack_beta_ti.models.chat_schedule_message_request import ChatScheduleMessageRequest
from slack_beta_ti.models.chat_schedule_message_success_schema import ChatScheduleMessageSuccessSchema
from slack_beta_ti.models.chat_scheduled_messages_list_error_schema import ChatScheduledMessagesListErrorSchema
from slack_beta_ti.models.chat_scheduled_messages_list_schema import ChatScheduledMessagesListSchema
from slack_beta_ti.models.chat_unfurl_error_schema import ChatUnfurlErrorSchema
from slack_beta_ti.models.chat_unfurl_request import ChatUnfurlRequest
from slack_beta_ti.models.chat_unfurl_success_schema import ChatUnfurlSuccessSchema
from slack_beta_ti.models.chat_update_error_schema import ChatUpdateErrorSchema
from slack_beta_ti.models.chat_update_request import ChatUpdateRequest
from slack_beta_ti.models.chat_update_success_schema import ChatUpdateSuccessSchema
from slack_beta_ti.models.conversations_archive_error_schema import ConversationsArchiveErrorSchema
from slack_beta_ti.models.conversations_archive_request import ConversationsArchiveRequest
from slack_beta_ti.models.conversations_archive_success_schema import ConversationsArchiveSuccessSchema
from slack_beta_ti.models.conversations_close_error_schema import ConversationsCloseErrorSchema
from slack_beta_ti.models.conversations_close_request import ConversationsCloseRequest
from slack_beta_ti.models.conversations_close_success_schema import ConversationsCloseSuccessSchema
from slack_beta_ti.models.conversations_create_error_schema import ConversationsCreateErrorSchema
from slack_beta_ti.models.conversations_create_request import ConversationsCreateRequest
from slack_beta_ti.models.conversations_create_success_schema import ConversationsCreateSuccessSchema
from slack_beta_ti.models.conversations_history_error_schema import ConversationsHistoryErrorSchema
from slack_beta_ti.models.conversations_history_success_schema import ConversationsHistorySuccessSchema
from slack_beta_ti.models.conversations_info_error_schema import ConversationsInfoErrorSchema
from slack_beta_ti.models.conversations_info_success_schema import ConversationsInfoSuccessSchema
from slack_beta_ti.models.conversations_invite_error_schema import ConversationsInviteErrorSchema
from slack_beta_ti.models.conversations_invite_error_schema1 import ConversationsInviteErrorSchema1
from slack_beta_ti.models.conversations_invite_request import ConversationsInviteRequest
from slack_beta_ti.models.conversations_join_error_schema import ConversationsJoinErrorSchema
from slack_beta_ti.models.conversations_join_request import ConversationsJoinRequest
from slack_beta_ti.models.conversations_join_success_schema import ConversationsJoinSuccessSchema
from slack_beta_ti.models.conversations_kick_error_schema import ConversationsKickErrorSchema
from slack_beta_ti.models.conversations_kick_request import ConversationsKickRequest
from slack_beta_ti.models.conversations_kick_success_schema import ConversationsKickSuccessSchema
from slack_beta_ti.models.conversations_leave_error_schema import ConversationsLeaveErrorSchema
from slack_beta_ti.models.conversations_leave_request import ConversationsLeaveRequest
from slack_beta_ti.models.conversations_leave_success_schema import ConversationsLeaveSuccessSchema
from slack_beta_ti.models.conversations_list_error_schema import ConversationsListErrorSchema
from slack_beta_ti.models.conversations_list_success_schema import ConversationsListSuccessSchema
from slack_beta_ti.models.conversations_mark_error_schema import ConversationsMarkErrorSchema
from slack_beta_ti.models.conversations_mark_request import ConversationsMarkRequest
from slack_beta_ti.models.conversations_mark_success_schema import ConversationsMarkSuccessSchema
from slack_beta_ti.models.conversations_members_error_schema import ConversationsMembersErrorSchema
from slack_beta_ti.models.conversations_members_success_schema import ConversationsMembersSuccessSchema
from slack_beta_ti.models.conversations_open_error_schema import ConversationsOpenErrorSchema
from slack_beta_ti.models.conversations_open_request import ConversationsOpenRequest
from slack_beta_ti.models.conversations_open_success_schema import ConversationsOpenSuccessSchema
from slack_beta_ti.models.conversations_rename_error_schema import ConversationsRenameErrorSchema
from slack_beta_ti.models.conversations_rename_request import ConversationsRenameRequest
from slack_beta_ti.models.conversations_rename_success_schema import ConversationsRenameSuccessSchema
from slack_beta_ti.models.conversations_replies_error_schema import ConversationsRepliesErrorSchema
from slack_beta_ti.models.conversations_replies_success_schema import ConversationsRepliesSuccessSchema
from slack_beta_ti.models.conversations_set_purpose_error_schema import ConversationsSetPurposeErrorSchema
from slack_beta_ti.models.conversations_set_purpose_request import ConversationsSetPurposeRequest
from slack_beta_ti.models.conversations_set_purpose_success_schema import ConversationsSetPurposeSuccessSchema
from slack_beta_ti.models.conversations_set_topic_error_schema import ConversationsSetTopicErrorSchema
from slack_beta_ti.models.conversations_set_topic_request import ConversationsSetTopicRequest
from slack_beta_ti.models.conversations_set_topic_success_schema import ConversationsSetTopicSuccessSchema
from slack_beta_ti.models.conversations_unarchive_error_schema import ConversationsUnarchiveErrorSchema
from slack_beta_ti.models.conversations_unarchive_request import ConversationsUnarchiveRequest
from slack_beta_ti.models.conversations_unarchive_success_schema import ConversationsUnarchiveSuccessSchema
from slack_beta_ti.models.default_error_template import DefaultErrorTemplate
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate
from slack_beta_ti.models.dialog_open_error_schema import DialogOpenErrorSchema
from slack_beta_ti.models.dialog_open_schema import DialogOpenSchema
from slack_beta_ti.models.dnd_end_dnd_error_schema import DndEndDndErrorSchema
from slack_beta_ti.models.dnd_end_dnd_schema import DndEndDndSchema
from slack_beta_ti.models.dnd_end_snooze_error_schema import DndEndSnoozeErrorSchema
from slack_beta_ti.models.dnd_end_snooze_schema import DndEndSnoozeSchema
from slack_beta_ti.models.dnd_info_error_schema import DndInfoErrorSchema
from slack_beta_ti.models.dnd_info_schema import DndInfoSchema
from slack_beta_ti.models.dnd_set_snooze_error_schema import DndSetSnoozeErrorSchema
from slack_beta_ti.models.dnd_set_snooze_schema import DndSetSnoozeSchema
from slack_beta_ti.models.files_comments_delete_error_schema import FilesCommentsDeleteErrorSchema
from slack_beta_ti.models.files_comments_delete_request import FilesCommentsDeleteRequest
from slack_beta_ti.models.files_comments_delete_schema import FilesCommentsDeleteSchema
from slack_beta_ti.models.files_delete_error_schema import FilesDeleteErrorSchema
from slack_beta_ti.models.files_delete_request import FilesDeleteRequest
from slack_beta_ti.models.files_delete_schema import FilesDeleteSchema
from slack_beta_ti.models.files_info_error_schema import FilesInfoErrorSchema
from slack_beta_ti.models.files_info_schema import FilesInfoSchema
from slack_beta_ti.models.files_list_error_schema import FilesListErrorSchema
from slack_beta_ti.models.files_list_schema import FilesListSchema
from slack_beta_ti.models.files_revoke_public_url_error_schema import FilesRevokePublicURLErrorSchema
from slack_beta_ti.models.files_revoke_public_url_request import FilesRevokePublicURLRequest
from slack_beta_ti.models.files_revoke_public_url_schema import FilesRevokePublicURLSchema
from slack_beta_ti.models.files_shared_public_url_error_schema import FilesSharedPublicURLErrorSchema
from slack_beta_ti.models.files_shared_public_url_request import FilesSharedPublicURLRequest
from slack_beta_ti.models.files_shared_public_url_schema import FilesSharedPublicURLSchema
from slack_beta_ti.models.files_upload_error_schema import FilesUploadErrorSchema
from slack_beta_ti.models.files_upload_schema import FilesUploadSchema
from slack_beta_ti.models.message_object import MessageObject
from slack_beta_ti.models.migration_exchange_error_schema import MigrationExchangeErrorSchema
from slack_beta_ti.models.migration_exchange_success_schema import MigrationExchangeSuccessSchema
from slack_beta_ti.models.objs_bot_profile import ObjsBotProfile
from slack_beta_ti.models.objs_channel import ObjsChannel
from slack_beta_ti.models.objs_comment import ObjsComment
from slack_beta_ti.models.objs_enterprise_user import ObjsEnterpriseUser
from slack_beta_ti.models.objs_external_org_migrations import ObjsExternalOrgMigrations
from slack_beta_ti.models.objs_external_org_migrations_current_inner import ObjsExternalOrgMigrationsCurrentInner
from slack_beta_ti.models.objs_file import ObjsFile
from slack_beta_ti.models.objs_icon import ObjsIcon
from slack_beta_ti.models.objs_message import ObjsMessage
from slack_beta_ti.models.objs_paging import ObjsPaging
from slack_beta_ti.models.objs_primary_owner import ObjsPrimaryOwner
from slack_beta_ti.models.objs_reaction import ObjsReaction
from slack_beta_ti.models.objs_reminder import ObjsReminder
from slack_beta_ti.models.objs_resources import ObjsResources
from slack_beta_ti.models.objs_subteam import ObjsSubteam
from slack_beta_ti.models.objs_team import ObjsTeam
from slack_beta_ti.models.objs_team_profile_field import ObjsTeamProfileField
from slack_beta_ti.models.objs_team_sso_provider import ObjsTeamSsoProvider
from slack_beta_ti.models.objs_user_profile import ObjsUserProfile
from slack_beta_ti.models.objs_user_profile_short import ObjsUserProfileShort
from slack_beta_ti.models.pins_add_error_schema import PinsAddErrorSchema
from slack_beta_ti.models.pins_add_request import PinsAddRequest
from slack_beta_ti.models.pins_add_schema import PinsAddSchema
from slack_beta_ti.models.pins_list_error_schema import PinsListErrorSchema
from slack_beta_ti.models.pins_remove_error_schema import PinsRemoveErrorSchema
from slack_beta_ti.models.pins_remove_request import PinsRemoveRequest
from slack_beta_ti.models.pins_remove_schema import PinsRemoveSchema
from slack_beta_ti.models.reactions_add_error_schema import ReactionsAddErrorSchema
from slack_beta_ti.models.reactions_add_request import ReactionsAddRequest
from slack_beta_ti.models.reactions_add_schema import ReactionsAddSchema
from slack_beta_ti.models.reactions_get_error_schema import ReactionsGetErrorSchema
from slack_beta_ti.models.reactions_list_error_schema import ReactionsListErrorSchema
from slack_beta_ti.models.reactions_list_schema import ReactionsListSchema
from slack_beta_ti.models.reactions_remove_error_schema import ReactionsRemoveErrorSchema
from slack_beta_ti.models.reactions_remove_request import ReactionsRemoveRequest
from slack_beta_ti.models.reactions_remove_schema import ReactionsRemoveSchema
from slack_beta_ti.models.reminders_add_error_schema import RemindersAddErrorSchema
from slack_beta_ti.models.reminders_add_request import RemindersAddRequest
from slack_beta_ti.models.reminders_add_schema import RemindersAddSchema
from slack_beta_ti.models.reminders_complete_error_schema import RemindersCompleteErrorSchema
from slack_beta_ti.models.reminders_complete_request import RemindersCompleteRequest
from slack_beta_ti.models.reminders_complete_schema import RemindersCompleteSchema
from slack_beta_ti.models.reminders_delete_error_schema import RemindersDeleteErrorSchema
from slack_beta_ti.models.reminders_delete_request import RemindersDeleteRequest
from slack_beta_ti.models.reminders_delete_schema import RemindersDeleteSchema
from slack_beta_ti.models.reminders_info_error_schema import RemindersInfoErrorSchema
from slack_beta_ti.models.reminders_info_schema import RemindersInfoSchema
from slack_beta_ti.models.reminders_list_error_schema import RemindersListErrorSchema
from slack_beta_ti.models.reminders_list_schema import RemindersListSchema
from slack_beta_ti.models.response_metadata import ResponseMetadata
from slack_beta_ti.models.rtm_connect_error_schema import RtmConnectErrorSchema
from slack_beta_ti.models.rtm_connect_schema import RtmConnectSchema
from slack_beta_ti.models.stars_add_error_schema import StarsAddErrorSchema
from slack_beta_ti.models.stars_add_request import StarsAddRequest
from slack_beta_ti.models.stars_add_schema import StarsAddSchema
from slack_beta_ti.models.stars_list_error_schema import StarsListErrorSchema
from slack_beta_ti.models.stars_list_schema import StarsListSchema
from slack_beta_ti.models.stars_remove_error_schema import StarsRemoveErrorSchema
from slack_beta_ti.models.stars_remove_request import StarsRemoveRequest
from slack_beta_ti.models.stars_remove_schema import StarsRemoveSchema
from slack_beta_ti.models.team_access_logs_error_schema import TeamAccessLogsErrorSchema
from slack_beta_ti.models.team_access_logs_schema import TeamAccessLogsSchema
from slack_beta_ti.models.team_info_error_schema import TeamInfoErrorSchema
from slack_beta_ti.models.team_info_schema import TeamInfoSchema
from slack_beta_ti.models.team_integration_logs_error_schema import TeamIntegrationLogsErrorSchema
from slack_beta_ti.models.team_integration_logs_schema import TeamIntegrationLogsSchema
from slack_beta_ti.models.team_profile_get_error_schema import TeamProfileGetErrorSchema
from slack_beta_ti.models.team_profile_get_success_schema import TeamProfileGetSuccessSchema
from slack_beta_ti.models.usergroups_create_error_schema import UsergroupsCreateErrorSchema
from slack_beta_ti.models.usergroups_create_request import UsergroupsCreateRequest
from slack_beta_ti.models.usergroups_create_schema import UsergroupsCreateSchema
from slack_beta_ti.models.usergroups_disable_error_schema import UsergroupsDisableErrorSchema
from slack_beta_ti.models.usergroups_disable_request import UsergroupsDisableRequest
from slack_beta_ti.models.usergroups_disable_schema import UsergroupsDisableSchema
from slack_beta_ti.models.usergroups_enable_error_schema import UsergroupsEnableErrorSchema
from slack_beta_ti.models.usergroups_enable_request import UsergroupsEnableRequest
from slack_beta_ti.models.usergroups_enable_schema import UsergroupsEnableSchema
from slack_beta_ti.models.usergroups_list_error_schema import UsergroupsListErrorSchema
from slack_beta_ti.models.usergroups_list_schema import UsergroupsListSchema
from slack_beta_ti.models.usergroups_update_error_schema import UsergroupsUpdateErrorSchema
from slack_beta_ti.models.usergroups_update_request import UsergroupsUpdateRequest
from slack_beta_ti.models.usergroups_update_schema import UsergroupsUpdateSchema
from slack_beta_ti.models.usergroups_users_list_error_schema import UsergroupsUsersListErrorSchema
from slack_beta_ti.models.usergroups_users_list_schema import UsergroupsUsersListSchema
from slack_beta_ti.models.usergroups_users_update_error_schema import UsergroupsUsersUpdateErrorSchema
from slack_beta_ti.models.usergroups_users_update_request import UsergroupsUsersUpdateRequest
from slack_beta_ti.models.usergroups_users_update_schema import UsergroupsUsersUpdateSchema
from slack_beta_ti.models.users_conversations_error_schema import UsersConversationsErrorSchema
from slack_beta_ti.models.users_conversations_success_schema import UsersConversationsSuccessSchema
from slack_beta_ti.models.users_counts_error_schema import UsersCountsErrorSchema
from slack_beta_ti.models.users_delete_photo_error_schema import UsersDeletePhotoErrorSchema
from slack_beta_ti.models.users_delete_photo_schema import UsersDeletePhotoSchema
from slack_beta_ti.models.users_identity_error_schema import UsersIdentityErrorSchema
from slack_beta_ti.models.users_info_error_schema import UsersInfoErrorSchema
from slack_beta_ti.models.users_info_success_schema import UsersInfoSuccessSchema
from slack_beta_ti.models.users_list_error_schema import UsersListErrorSchema
from slack_beta_ti.models.users_list_schema import UsersListSchema
from slack_beta_ti.models.users_lookup_by_email_error_schema import UsersLookupByEmailErrorSchema
from slack_beta_ti.models.users_lookup_by_email_success_schema import UsersLookupByEmailSuccessSchema
from slack_beta_ti.models.users_profile_get_error_schema import UsersProfileGetErrorSchema
from slack_beta_ti.models.users_profile_get_schema import UsersProfileGetSchema
from slack_beta_ti.models.users_profile_set_error_schema import UsersProfileSetErrorSchema
from slack_beta_ti.models.users_profile_set_request import UsersProfileSetRequest
from slack_beta_ti.models.users_profile_set_schema import UsersProfileSetSchema
from slack_beta_ti.models.users_set_active_error_schema import UsersSetActiveErrorSchema
from slack_beta_ti.models.users_set_active_schema import UsersSetActiveSchema
from slack_beta_ti.models.users_set_photo_error_schema import UsersSetPhotoErrorSchema
from slack_beta_ti.models.users_set_photo_schema import UsersSetPhotoSchema
from slack_beta_ti.models.users_set_presence_error_schema import UsersSetPresenceErrorSchema
from slack_beta_ti.models.users_set_presence_request import UsersSetPresenceRequest
from slack_beta_ti.models.users_set_presence_schema import UsersSetPresenceSchema



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_channel import ObjsChannel

class TestObjsChannel(unittest.TestCase):
    """ObjsChannel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsChannel:
        """Test ObjsChannel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsChannel`
        """
        model = ObjsChannel()
        if include_optional:
            return ObjsChannel(
                accepted_user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                created = 56,
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                is_archived = True,
                is_channel = True,
                is_frozen = True,
                is_general = True,
                is_member = True,
                is_moved = 56,
                is_mpim = True,
                is_non_threadable = True,
                is_org_shared = True,
                is_pending_ext_shared = True,
                is_private = True,
                is_read_only = True,
                is_shared = True,
                is_thread_only = True,
                last_read = '0480728880.015280',
                latest = None,
                members = [
                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                name = '',
                name_normalized = '',
                num_members = 56,
                pending_shared = [
                    'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                previous_names = [
                    ''
                    ],
                priority = 1.337,
                purpose = None,
                topic = None,
                unlinked = 56,
                unread_count = 56,
                unread_count_display = 56
            )
        else:
            return ObjsChannel(
                created = 56,
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                is_channel = True,
                is_mpim = True,
                is_org_shared = True,
                is_private = True,
                is_shared = True,
                members = [
                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                name = '',
                name_normalized = '',
                purpose = None,
                topic = None,
        )
        """

    def testObjsChannel(self):
        """Test ObjsChannel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthApi()

    def tearDown(self) -> None:
        pass

    def test_auth_revoke(self) -> None:
        """Test case for auth_revoke

        """
        pass

    def test_auth_test(self) -> None:
        """Test case for auth_test

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.admin_conversations_invite_schema import AdminConversationsInviteSchema

class TestAdminConversationsInviteSchema(unittest.TestCase):
    """AdminConversationsInviteSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminConversationsInviteSchema:
        """Test AdminConversationsInviteSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminConversationsInviteSchema`
        """
        model = AdminConversationsInviteSchema()
        if include_optional:
            return AdminConversationsInviteSchema(
                ok = True
            )
        else:
            return AdminConversationsInviteSchema(
                ok = True,
        )
        """

    def testAdminConversationsInviteSchema(self):
        """Test AdminConversationsInviteSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.usergroups_create_schema import UsergroupsCreateSchema

class TestUsergroupsCreateSchema(unittest.TestCase):
    """UsergroupsCreateSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsergroupsCreateSchema:
        """Test UsergroupsCreateSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsergroupsCreateSchema`
        """
        model = UsergroupsCreateSchema()
        if include_optional:
            return UsergroupsCreateSchema(
                ok = True,
                usergroup = slack_beta_ti.models.subteam/usergroup_object.Subteam/Usergroup Object(
                    auto_provision = True, 
                    auto_type = slack_beta_ti.models.auto_type.auto_type(), 
                    channel_count = 56, 
                    created_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    date_create = 56, 
                    date_delete = 56, 
                    date_update = 56, 
                    deleted_by = slack_beta_ti.models.deleted_by.deleted_by(), 
                    description = '', 
                    enterprise_subteam_id = '', 
                    handle = '', 
                    id = 'S8Q6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKT', 
                    is_external = True, 
                    is_subteam = True, 
                    is_usergroup = True, 
                    name = '', 
                    prefs = slack_beta_ti.models.prefs.prefs(), 
                    team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    updated_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_count = 56, 
                    users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], )
            )
        else:
            return UsergroupsCreateSchema(
                ok = True,
                usergroup = slack_beta_ti.models.subteam/usergroup_object.Subteam/Usergroup Object(
                    auto_provision = True, 
                    auto_type = slack_beta_ti.models.auto_type.auto_type(), 
                    channel_count = 56, 
                    created_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    date_create = 56, 
                    date_delete = 56, 
                    date_update = 56, 
                    deleted_by = slack_beta_ti.models.deleted_by.deleted_by(), 
                    description = '', 
                    enterprise_subteam_id = '', 
                    handle = '', 
                    id = 'S8Q6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKT', 
                    is_external = True, 
                    is_subteam = True, 
                    is_usergroup = True, 
                    name = '', 
                    prefs = slack_beta_ti.models.prefs.prefs(), 
                    team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    updated_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_count = 56, 
                    users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], ),
        )
        """

    def testUsergroupsCreateSchema(self):
        """Test UsergroupsCreateSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.apps_permissions_info_schema import AppsPermissionsInfoSchema

class TestAppsPermissionsInfoSchema(unittest.TestCase):
    """AppsPermissionsInfoSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppsPermissionsInfoSchema:
        """Test AppsPermissionsInfoSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppsPermissionsInfoSchema`
        """
        model = AppsPermissionsInfoSchema()
        if include_optional:
            return AppsPermissionsInfoSchema(
                info = slack_beta_ti.models.apps_permissions_info_schema_info.apps_permissions_info_schema_info(
                    app_home = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            excluded_ids = [
                                None
                                ], 
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), 
                    channel = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(), 
                    group = , 
                    im = , 
                    mpim = , 
                    team = slack_beta_ti.models.apps_permissions_info_schema_info_team.apps_permissions_info_schema_info_team(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), ),
                ok = True
            )
        else:
            return AppsPermissionsInfoSchema(
                info = slack_beta_ti.models.apps_permissions_info_schema_info.apps_permissions_info_schema_info(
                    app_home = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            excluded_ids = [
                                None
                                ], 
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), 
                    channel = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(), 
                    group = , 
                    im = , 
                    mpim = , 
                    team = slack_beta_ti.models.apps_permissions_info_schema_info_team.apps_permissions_info_schema_info_team(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), ),
                ok = True,
        )
        """

    def testAppsPermissionsInfoSchema(self):
        """Test AppsPermissionsInfoSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
